@@ -6,7 +6,7 @@ no warnings qw(void once uninitialized numeric);
 package Moops::Parser;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.017';
+our $VERSION   = '0.018';
 
 use Moo;
 use Module::Runtime qw($module_name_rx);
@@ -193,7 +193,7 @@ sub parse
 
 sub keywords
 {
-	qw/ class role namespace /;
+	qw/ class role namespace library /;
 }
 
 sub qualify_module_name
@@ -224,6 +224,11 @@ sub _build_class_for_keyword
 		require Moops::Keyword::Role;
 		return 'Moops::Keyword::Role';
 	}
+	elsif ($kw eq 'library')
+	{
+		require Moops::Keyword::Library;
+		return 'Moops::Keyword::Library';
+	}
 	
 	require Moops::Keyword;
 	return 'Moops::Keyword';
